#!/system/bin/sh
# Please don't hardcode /magisk/modname/... ; instead, please use $MODDIR/...
# This will make your scripts compatible even if Magisk change its mount point in the future
MODDIR=${0%/*}

# This script will be executed in post-fs-data mode
# More info in the main Magisk thread

# Magisk Module variable
DarkModeSysFile=/system_ext/etc/forcedarkconfig/ForceDarkAppSettings.json
SysPackageListFile=/data/system/packages.list
# Module's folder
DarkModeModFileFolder=$MODDIR/system/system_ext/etc/forcedarkconfig
DarkModeModFile=$DarkModeModFileFolder/ForceDarkAppSettings.json

# Functions
set_perm() {
  chown $2:$3 $1 || return 1
  chmod $4 $1 || return 1
}

# Check dark mode sys file exists
if [ -f $DarkModeSysFile -a -f $SysPackageListFile ]; 
then
    # Read dark mode sys file
    DarkModeSysFileContent=`cat $DarkModeSysFile`
    
    # Check dark mode sys file is empty
    if [ -z "$DarkModeSysFileContent" ]; 
    then
        # If it is empty, initialize it with empty json
        DarkModeSysFileContent="["$'\n'"]"$'\n' 
    fi
    
    # Get dark mode sys file first line
    FirstLine=`echo "$DarkModeSysFileContent" | head -1`
    
    # Check first line is valid json begin
    if [ "$FirstLine" = "[" ]; 
    then
        # Clear current dark mode file list and refresh with system file
        if [ -f $DarkModeModFile ]; 
        then
            rm -f $DarkModeModFile 
        fi
        cp $DarkModeSysFile $DarkModeModFile
        
        # List user packages
        Packages=$(awk '{ if (($2 != "1000")&&($10 != "@system")&&($10 != "@null")&&($1!~/trichrome/)) {print $1} }' $SysPackageListFile)
        for PackageInfo in $Packages
        do
            if ! echo "$DarkModeSysFileContent" | grep -Fq "$PackageInfo"; 
            then
                DarkModeLine="{\"defaultEnable\":true,\"overrideEnableValue\":0,\"packageName\":\""$PackageInfo"\",\"showInSettings\":true},"
                
                # Add user package to dark mode mod file to enable dark mode
                sed -i "1 a $DarkModeLine" $DarkModeModFile
            fi
        done
        
        # Reset permissions
        set_perm $DarkModeModFile 0 0 0644
    fi
fi

exit 0
